pub struct Entry {
pub compression_type: u8,
pub _reserved: u8,
/* private fields */
}Expand description
Metadata for an entry in the archive.
Contains information about stored files including offset, size, compression, and CRC32 checksum.
Retrieved via the archive’s index() method.
Fields
compression_type: u8_reserved: u8Implementations
Sourceimpl Entry
impl Entry
Sourcepub fn offset(&self) -> u64
pub fn offset(&self) -> u64
Returns the byte offset where this entry’s data starts in the archive.
Sourcepub fn compressed_size(&self) -> u64
pub fn compressed_size(&self) -> u64
Returns the compressed size of this entry in bytes.
Sourcepub fn uncompressed_size(&self) -> u64
pub fn uncompressed_size(&self) -> u64
Returns the uncompressed size of this entry in bytes.
Sourcepub fn compression_type(&self) -> Compress
pub fn compression_type(&self) -> Compress
Returns the compression type for this entry.