Bindle is a binary archive format for collecting files.
The format uses memory-mapped I/O for fast reads, optional zstd compression, and supports append-only writes with shadowing for updates.
Example
use bindle_file::{Bindle, Compress};
let mut archive = Bindle::open("data.bndl")?;
archive.add("file.txt", b"data", Compress::None)?;
archive.save()?;
let data = archive.read("file.txt").unwrap();Structs
- Bindle
- A binary archive for collecting files.
- Entry
- Metadata for an entry in the archive.
- Reader
- A streaming reader for archive entries.
- Writer
- A streaming writer for adding entries to an archive.
Enums
- Compress
- Compression mode for entries.